<?php

// Load text domain.
add_action( 'init', 'growmatik_i18n' );

function growmatik_i18n() {
	load_plugin_textdomain( 'growmatik', false, GROWMATIK_PATH . 'languages' );
}

// Fix hidden links in emails.
add_filter( 'wp_new_user_notification_email', 'growmatik_modify_new_user_notification_email', 99, 3 );

function growmatik_modify_new_user_notification_email( $email, $user, $blogname ) {
	$email['message'] = preg_replace( '/<(' . preg_quote( network_site_url(), '/' ) . '[^>]*)>/', '\1', $email['message'] );
	return $email;
}

// Add custom data attribute to if-then script.
add_filter( 'script_loader_tag', 'growmatik_script_custom_attrs', 10, 3 );

function growmatik_script_custom_attrs( $tag, $handle ) {
	if ( 'growmatik-if-then' === $handle || 'growmatik-automations' === $handle ) {
		$tag = str_replace( ' src=', ' data-minify="0" src=', $tag ); //phpcs:ignore
	}
	return $tag;
}

// Exclude growmatik scripts from Autoptimize.
add_filter( 'autoptimize_filter_js_exclude', 'growmatik_compatibility_autoptimize' );

function growmatik_compatibility_autoptimize( $excluded_js_files ) {
	$growmatik_files = 'growmatik-public.js, if-then.min.js, _growmatik, automations.js';
	return $excluded_js_files . ', ' . $growmatik_files;
}

add_filter( 'litespeed_optimize_js_excludes', 'growmatik_compatibility_litespeed_cache' );
/**
 * Exclude growmatik scripts from LiteSpeed Cache.
 *
 * @link https://github.com/litespeedtech/lscache_wp/blob/ec2d7a26272a7e65f8ebac3084343323506e5b40/src/optimize.cls.php#L805-L882
 */
function growmatik_compatibility_litespeed_cache( $files ) {
	$files[] = 'growmatik-public.js';
	$files[] = 'if-then.min.js';
	$files[] = 'automations.js';
	return $files;
}

// Exclude growmatik inline scripts from WP Rocket.
add_filter( 'rocket_excluded_inline_js_content', 'growmatik_compatibility_wp_rocket_inline_scripts' );

function growmatik_compatibility_wp_rocket_inline_scripts( array $excluded_files ) {
	$excluded_files[] = '_growmatik';
	return $excluded_files;
}

// Exclude growmatik external scripts from WP Rocket.
add_filter( 'rocket_minify_excluded_external_js', 'growmatik_compatibility_wp_rocket' );

function growmatik_compatibility_wp_rocket( array $excluded_files ) {
	$excluded_files[] = 'growmatik.ai';
	return $excluded_files;
}
