<?php

namespace Growmatik\Plugin_Integration\Elementor;

use ElementorPro\Modules\Forms\Classes\Action_Base;
use Elementor\Repeater;
use Elementor\Controls_Manager;
use Growmatik\Plugin_Integration\Integration;

class Elementor_Form_Growmatik_Action extends Action_Base {

	private $growmatik_tags;
	private $all_attributes = array();

	public function get_name() {
		return 'growmatik';
	}

	public function get_label() {
		return __( 'Growmatik', 'growmatik' );
	}

	public function update_growmatik_attributes() {
		$this->all_attributes = Integration::instance()->get_all_attributes();
		$this->growmatik_tags = Integration::instance()->get_tags();
	}

	/**
	 * Add Growmatik settings section in Elementor form widget.
	 */
	public function register_settings_section( $element ) {
		$this->update_growmatik_attributes();

		$element->start_controls_section(
			'section_growmatik',
			array(
				'tab'       => 'content',
				'label'     => __( 'Growmatik', 'growmatik' ),
				'condition' => array(
					'submit_actions' => $this->get_name(),
				),
			)
		);

		$element->add_control(
			'growmatik_form_name',
			array(
				'type'     => Controls_Manager::TEXT,
				'label'    => __( 'Form Name', 'gromatik' ),
				'required' => true,
			)
		);

		$element->add_control(
			'growmatik_form_tags',
			array(
				'type'        => Controls_Manager::SELECT2,
				'label'       => __( 'Tags', 'growmatik' ),
				'description' => __( 'Add comma separated tags', 'growmatik' ),
				'multiple'    => true,
				'options'     => $this->growmatik_tags,
			)
		);

		$element->add_control(
			'gromatik_heading_field_mapping',
			array(
				'type'  => Controls_Manager::HEADING,
				'label' => __( 'Field Mapping', 'growmatik' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'growmatik_attribute',
			array(
				'label'   => __( 'Attribute', 'growmatik' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array( '' => '- None -' ) + $this->all_attributes,
				'default' => '',
			)
		);

		$repeater->add_control(
			'growmatik_form_field',
			array(
				'label'   => __( 'Form Field', 'growmatik' ),
				'type'    => Controls_Manager::SELECT,
				'options' => array(// Will be updated by JS while changing form fields.
					'' => __( '- None -', 'growmatik' ),
				),
				'default' => '',
			)
		);

		$element->add_control(
			'growmatik_mapping_fields',
			array(
				'type'          => Controls_Manager::REPEATER,
				'fields'        => $repeater->get_controls(),
				'title_field'   => '{{ growmatik_form_field }}',
				'prevent_empty' => true,
				'default'       => array(
					'growmatik_attribute'  => '',
					'growmatik_form_field' => '',
				),
			)
		);

		$element->end_controls_section();
	}

	/**
	 * Run
	 *
	 * Runs the action after submit
	 *
	 * @access public
	 * @param \ElementorPro\Modules\Forms\Classes\Form_Record  $record
	 * @param \ElementorPro\Modules\Forms\Classes\Ajax_Handler $ajax_handler
	 */
	public function run( $record, $ajax_handler ) {
		$this->update_growmatik_attributes();

		$settings   = $record->get( 'form_settings' );
		$raw_fields = $record->get( 'fields' );
		$all_fields = array();
		$site_id    = get_option( 'growmatik_site_id' );
		$tags       = $settings['growmatik_form_tags'];
		$form_name  = $settings['growmatik_form_name'];

		// Get value of default and custom mapped fields.
		foreach ( $settings['growmatik_mapping_fields'] as $field_key => $value ) {

			$field_id = $value['growmatik_form_field'];

			if ( $field_id ) {
				$growmatik_field = str_replace( 'growmatik-', '', $value['growmatik_attribute'] );

				$field = array(
					'key'   => $growmatik_field,
					'value' => $raw_fields[ $field_id ]['value'],
					'type'  => Integration::instance()->get_attribute_type( $growmatik_field ),
				);

				array_push( $all_fields, $field );
			}
		}

		$form_data = array(
			'siteId'   => $site_id,
			'formName' => $form_name,
			'tags'     => $tags,
			'formData' => $all_fields,
		);

		$response = Integration::instance()->form_submission( $form_data );

		if ( is_wp_error( $response ) ) {
			$ajax_handler->add_admin_error_message( 'Growmatik: Internal server error.' );
		} elseif ( ! $response['success'] ) {
			$ajax_handler->add_admin_error_message( 'Growmatik: Could not send the form successfuly.' );
		}
	}

	/**
	 * On Export
	 *
	 * Clears form settings on export
	 *
	 * @access public
	 * @param array $element
	 */
	public function on_export( $element ) {
		foreach ( $this->growmatik_fields as $fields_key => $label ) {
			unset( $element[ 'growmatik_mapping_fields_' . $fields_key ] );
		}
	}
}
