<?php

namespace Growmatik\Plugin_Integration\Gravityforms;

use Growmatik\Plugin_Integration\Integration;

class Form {

	public function __construct() {
		add_action( 'gform_field_standard_settings', array( $this, 'add_settings' ), 10, 2 );
		add_action( 'gform_editor_js', array( $this, 'editor_script' ) );
		add_action( 'gform_after_submission', array( $this, 'after_submission' ), 10, 2 );
	}

	public function add_settings( $section_id, $form_id ) {
		if ( -1 !== $section_id ) {
			return;
		}

		$all_attributes = Integration::instance()->get_all_attributes();

		?>
		<li class="growmatik_setting field_setting">
			<label for="growmatik_field_mapping" class="section_label">
				<?php esc_html_e( 'Map to Growmatik field', 'growmatik' ); ?>
			</label>
			<select id="growmatik_field_mapping" onchange="SetFieldProperty('growmatikField', jQuery(this).val());">
				<option value="none"><?php esc_html_e( '-None-', 'growmatic' ); ?></option>

				<?php
				foreach ( $all_attributes as $key => $label ) :
					?>
					<option value="<?php echo esc_attr( $key ); ?>"><?php echo esc_html( $label ); ?></option>
					<?php
				endforeach;
				?>
			</select>
		</li>

		<?php

	}

	public function editor_script() {
		?>
		<script type='text/javascript'>
			let excluded = [
				'list',
				'name',
				'address',
				'fileupload',
				'consent',
				'creditcard',
				'captcha',
				'repeater',
				'password',
				'calculation',
			];
			// Add Growmatik settings to all of the existing fields.
			for (let settings in fieldSettings) {
				if ( -1 === excluded.indexOf( settings ) ){
					fieldSettings[settings] += ', .growmatik_setting';
				}
			}

			// binding to the load field settings event to initialize the checkbox.
			jQuery(document).on('gform_load_field_settings', function(event, field, form){
				jQuery('#growmatik_field_mapping').val(field.growmatikField || 'none' );
			});
		</script>
		<?php
	}

	public function after_submission( $entry, $form ) {

		$form_data = array();

		$form_data['siteId']   = get_option( 'growmatik_site_id' );
		$form_data['formName'] = $form['title'];
		$form_data['tags']     = array();

		foreach ( $form['fields'] as $field ) {
			$field_value = rgar( $entry, (string) $field->id, null );
			if ( isset( $field['growmatikField'] ) && 'none' !== $field['growmatikField'] ) {
				$growmatik_field         = str_replace( 'growmatik-', '', $field['growmatikField'] );
				$form_data['formData'][] = array(
					'key'   => $growmatik_field,
					'value' => $field_value,
					'type'  => Integration::instance()->get_attribute_type( $growmatik_field ),
				);
			}
		}

		$response = Integration::instance()->form_submission( $form_data );

		if ( is_wp_error( $response ) ) {
			error_log( __( 'Growmatik: Internal server error.', 'growmatik' ) ); // phpcs:ignore
		} elseif ( isset( $response['errors'] ) && isset( $response['error']['api_error'] ) ) {
			error_log( (string) $response['error']['api_error'][0] ); // phpcs:ignore
		}

	}

}
