<?php
namespace Growmatik\Plugin_Integration\Raven;

use Growmatik\Plugin_Integration\Integration;
use JupiterX_Core\Raven\Modules\Forms\Actions\Action_Base;
use Elementor\Repeater;

class Raven_Form_Growmatik_Action extends Action_Base {

	public $growmatik_tags;
	private $all_attributes = array();

	public function __construct() {
		add_action( 'elementor/element/raven-form/section_settings/after_section_end', array( $this, 'update_controls' ) );
	}

	public function get_name() {
		return 'growmatik';
	}

	public function get_title() {
		return __( 'Growmatik', 'jupiterx-core' );
	}

	public function update_growmatik_attributes() {
		$this->all_attributes = Integration::instance()->get_all_attributes();
		$this->growmatik_tags = Integration::instance()->get_tags();
	}

	public function update_controls( $widget ) {
		$this->update_growmatik_attributes();

		$widget->start_controls_section(
			'section_growmatik',
			array(
				'label'     => __( 'Growmatik', 'jupiterx-core' ),
				'condition' => array(
					'actions' => $this->get_name(),
				),
			)
		);

		$widget->add_control(
			'growmatik_form_name',
			array(
				'type'     => 'text',
				'label'    => __( 'Form Name', 'gromatik' ),
				'required' => true,
			)
		);

		$widget->add_control(
			'growmatik_form_tags',
			array(
				'type'        => 'select2',
				'label'       => __( 'Tags', 'growmatik' ),
				'description' => __( 'Add comma separated tags', 'growmatik' ),
				'multiple'    => true,
				'options'     => $this->growmatik_tags,
			)
		);

		$widget->add_control(
			'gromatik_heading_field_mapping',
			array(
				'type'  => 'heading',
				'label' => __( 'Field Mapping', 'growmatik' ),
			)
		);

		$repeater = new Repeater();

		$repeater->add_control(
			'growmatik_attribute',
			array(
				'label'   => __( 'Attribute', 'growmatik' ),
				'type'    => 'select',
				'options' => array( '' => '- None -' ) + $this->all_attributes,
				'default' => '',
			)
		);

		$repeater->add_control(
			'growmatik_form_field',
			array(
				'label'   => __( 'Form Field', 'growmatik' ),
				'type'    => 'select',
				'options' => array(
					'' => __( '- None -', 'growmatik' ),
				),
				'default' => '',
			)
		);

		$widget->add_control(
			'growmatik_mapping_fields',
			array(
				'type'          => 'repeater',
				'fields'        => $repeater->get_controls(),
				'title_field'   => '{{growmatik_form_field}}',
				'prevent_empty' => true,
				'default'       => array(
					'growmatik_attribute'  => '',
					'growmatik_form_field' => '',
				),
			)
		);

		$widget->end_controls_section();
	}

	public static function run( $ajax_handler ) {
		$form     = $ajax_handler->form;
		$settings = $form['settings'];

		$all_fields = array();
		$site_id    = get_option( 'growmatik_site_id' );
		$tags       = isset( $settings['growmatik_form_tags'] ) ? $settings['growmatik_form_tags'] : '';
		$form_name  = isset( $settings['growmatik_form_name'] ) ? $settings['growmatik_form_name'] : '';

		// Get value of default and custom mapped fields.
		foreach ( $settings['growmatik_mapping_fields'] as $field_key => $value ) {

			$field_id = $value['growmatik_form_field'];

			if ( $field_id ) {
				$growmatik_field = str_replace( 'growmatik-', '', $value['growmatik_attribute'] );

				$field = array(
					'key'   => $growmatik_field,
					'value' => $ajax_handler->record['fields'][ $field_id ],
					'type'  => Integration::instance()->get_attribute_type( $growmatik_field ),
				);

				array_push( $all_fields, $field );
			}
		}

		$form_data = array(
			'siteId'   => $site_id,
			'formName' => $form_name,
			'tags'     => $tags,
			'formData' => $all_fields,
		);

		$response = Integration::instance()->form_submission( $form_data );

		if ( is_wp_error( $response ) ) {
			error_log( __( 'Growmatik: Internal server error.', 'growmatik' ) ); // phpcs:ignore
		} elseif ( isset( $response['errors'] ) && isset( $response['error']['api_error'] ) ) {
			error_log( (string) $response['error']['api_error'][0] ); // phpcs:ignore
		}
	}
}
